@@ -1,10 +1,14 @@
 use clap::clap_app;
 
 use crate::ross_configurator::{RossConfiguratorError, DEFAULT_BAUDRATE};
-use crate::get_info::get_info;
+use crate::ross_serial::RossSerial;
+use crate::get_programmer::get_programmer;
+use crate::get_devices::get_devices;
 
 mod ross_configurator;
-mod get_info;
+mod ross_serial;
+mod get_programmer;
+mod get_devices;
 
 fn main() -> Result<(), RossConfiguratorError> {
     let matches = clap_app!(ross_configurator =>
@@ -14,8 +18,11 @@ fn main() -> Result<(), RossConfiguratorError> {
         (about: env!("CARGO_PKG_DESCRIPTION"))
         (@arg DEVICE: -d --device +required +takes_value "Path of device to use")
         (@arg BAUDRATE: -b --baudrate +takes_value "Baudrate to use")
-        (@subcommand get_info => 
-            (about: "Gets connected programmer information")
+        (@subcommand get_programmer => 
+            (about: "Gets connected programmer's information")
+        )
+        (@subcommand get_devices =>
+            (about: "Gets connected devices' information")
         )
     ).get_matches();
 
@@ -31,12 +38,29 @@ fn main() -> Result<(), RossConfiguratorError> {
             }
         },
         None => DEFAULT_BAUDRATE,
+    };    
+    
+    let mut serial = {        
+        let port = match serialport::new(device, baudrate).open() {
+            Ok(port) => port,
+            Err(err) => {
+                eprintln!("Failed to open device.");
+                return Err(RossConfiguratorError::FailedToOpenDevice(err));
+            }
+        };
+
+        RossSerial::new(port)
     };
 
     match matches.subcommand() {
-        ("get_info", _) => {
-            get_info(device, baudrate)
+        ("get_programmer", _) => {
+            get_programmer(&mut serial)?;
+            Ok(())
         },
+        ("get_devices", _) => {
+            get_devices(&mut serial)?;
+            Ok(())
+        }
         (_, _) => {
             Ok(())
         },
