@@ -1,3 +1,5 @@
+use crate::ross_serial::RossSerialError;
+
 pub const PACKET_TIMEOUT_MS: u128 = 500;
 pub const DEFAULT_BAUDRATE: u32 = 9_600;
 
@@ -5,4 +7,5 @@ pub const DEFAULT_BAUDRATE: u32 = 9_600;
 pub enum RossConfiguratorError {
     BadUsage,
     FailedToOpenDevice(serialport::Error),
+    SerialError(RossSerialError),
 }
